@@ -12,12 +12,13 @@ from agentbox.exceptions import SandboxException, format_request_timeout_error
 from agentbox.sandbox.main import SandboxSetup
 from agentbox.sandbox.utils import class_method_variant
 from agentbox.sandbox_sync.adb_shell.adb_shell import ADBShell
-from agentbox.sandbox_sync.filesystem.filesystem import Filesystem
+from agentbox.sandbox_sync.filesystem.filesystem import AgentBoxFilesystem as Filesystem
 from agentbox.sandbox_sync.commands.command import Commands
 from agentbox.sandbox_sync.commands.pty import Pty
 from agentbox.sandbox_sync.sandbox_api import SandboxApi, SandboxInfo
 from agentbox.sandbox_sync.commands_ssh.command_ssh import SSHCommands
 from agentbox.sandbox_sync.filesystem_ssh.filesystem_ssh import SSHSyncFilesystem
+from agentbox.sandbox_sync.commands_ssh2.command_ssh2 import SSHCommands2
 
 logger = logging.getLogger(__name__)
 
@@ -186,7 +187,7 @@ class Sandbox(SandboxSetup, SandboxApi):
                 request_timeout=request_timeout,
                 proxy=proxy,
             )
-            print("ssh_info:", ssh_info)
+            # print("ssh_info:", ssh_info)
             # Parse SSH connection details from the connect command
             pattern = r'ssh\s+-p\s+(\d+).*?\s+([^@\s]+)@([\w\.-]+)'
             ssh_match = re.search(pattern, ssh_info.connect_command)
@@ -240,7 +241,7 @@ class Sandbox(SandboxSetup, SandboxApi):
                 request_timeout=request_timeout,
                 proxy=proxy,
             )
-            print("ssh_info:", ssh_info)
+            # print("ssh_info:", ssh_info)
             # Parse SSH connection details from the connect command
             pattern = r'ssh\s+-p\s+(\d+).*?\s+([^@\s]+)@([\w\.-]+)'
             ssh_match = re.search(pattern, ssh_info.connect_command)
@@ -271,14 +272,28 @@ class Sandbox(SandboxSetup, SandboxApi):
 
         # 根据 sandbox id 进行区分 commands 类型
         if "brd" in self._sandbox_id.lower():
-            self._watch_commands = SSHCommands(
+            # self._watch_commands = SSHCommands(
+            #     self._ssh_host,
+            #     self._ssh_port,
+            #     self._ssh_username,
+            #     self._ssh_password,
+            #     self.connection_config,
+            # )
+            # self._commands = SSHCommands(
+            #     self._ssh_host,
+            #     self._ssh_port,
+            #     self._ssh_username,
+            #     self._ssh_password,
+            #     self.connection_config,
+            # )
+            self._watch_commands = SSHCommands2(
                 self._ssh_host,
                 self._ssh_port,
                 self._ssh_username,
                 self._ssh_password,
                 self.connection_config,
             )
-            self._commands = SSHCommands(
+            self._commands = SSHCommands2(
                 self._ssh_host,
                 self._ssh_port,
                 self._ssh_username,
@@ -453,7 +468,7 @@ class Sandbox(SandboxSetup, SandboxApi):
         if request_timeout:
             config_dict["request_timeout"] = request_timeout
 
-        SandboxApi._cls_kill(
+        return SandboxApi._cls_kill(
             sandbox_id=self.sandbox_id,
             **config_dict,
         )
